{% layout 'layouts/html.liquid' %}

{% block head %}
<title>smartsite</title>
<style>
    hr { margin: 60px 0; }

    .book-heading { margin-bottom: 60px;}
    .image-col { text-align: center; }
    .book-cover { width: 50%; border: 2px solid #ddd; box-shadow: 2px 2px 5px #ddd;}
    .login-cta { margin-bottom: 60px; border: 1px solid black; padding: 20px; font-size: 1.2em; }

    .book { color: #444; }
    .book h1, .book h2, .book h3, .book h4, .book h5, .book h6 { color: #000; }
    .book h2:not(:first-of-type), .book h3, .book h4, .book h5, .book h6 { margin-top: 60px; }
    .book video { max-width: 80%; max-height: 45vh; border: 1px solid #ddd; box-shadow: #ddd 5px 5px 5px; padding: 2%; }
    .book img { max-width: 80%; max-height: 45vh; border: 1px solid #ddd; box-shadow: #ddd 5px 5px 5px; padding: 2%; }
    .book pre { background-color: #f5f5f5; padding: 2%; border-radius: 2%; border: 1px solid #ddd; white-space: break-spaces }
    .book code { background-color: #f5f5f5; }

    #read-view { display: flex; }

    .sections-menu-heading { background-color:#222;color:white;font-weight:bold; padding:5px; font-size:.9em; }
    .book-section-tab {
        text-align: left;
        padding: 5px;
        color: #444;
        font-size: .9em;
        border-radius: 0 !important;
        background-color: #eee !important;
    }
    .book-section-tab.active {
        color: black !important;
        background-color: #fff !important;
        border-top: 1px solid #222;
        border-bottom: 1px solid #222;
    }

    .section-tools { display: flex; justify-content: space-between; margin-top: 60px; }

</style>
{% endblock %}

{% block content %}

<div class="book-heading">
    <div class="container">
        <div class="row">
            <div class="col-6">
                <h1 id="book-title">{{ book.title }}</h1>
                <p><em>{{ book.brief }}</em></p>
            </div>
            <div class="col-6 image-col">
                <img src="{{ book.image }}" class="book-cover" alt="cover for book {{ book.title }}">
            </div>
        </div>
    </div>
    <hr/>
</div>

<div class="book">
    {% if book.pdf %}
        <object width="100%" height="500" type="application/pdf" data="{{ book.pdf }}?#view=FitH&scrollbar=0&toolbar=0&navpanes=0">
            <p>This pdf cannot be displayed. <button onclick="history.back()">go back</button></p>
        </object>
        <p><b>{{ book.title }} by {{ book.author }}</b></p>
    {% else %}
    <div id="read-view">
        <div class="container">
            <div class="row gy-5">
                <div class="left-column col-lg-3">
                    <div class="d-flex align-items-start">
                        <div class="nav flex-column nav-pills w-100" id="bookSectionTabs" role="tablist" aria-orientation="vertical">
                            <div class="sections-menu-heading">Table of Contents</div>
                            {% for section in book.sections %}
                                <button class="nav-link {{ 'active' |  if: forloop.first }} book-section-tab" id="{{ section.slug }}-tab" data-book-section-slug="{{ section.slug }}" data-bs-toggle="pill" data-bs-target="#{{ section.slug }}-page" type="button" role="tab" aria-controls="v-pills-home" aria-selected="true">{{ section.title }}</button>
                            {% endfor %}
                        </div>
                    </div>
                </div>
                <div class="right-column col-lg-9">
                    <div class="tab-content" id="bookSectionContent">
                        {% for section in book.sections %}
                            <div class="tab-pane fade show {{ 'active' |  if: forloop.first }}" id="{{ section.slug }}-page" role="tabpanel" aria-labelledby="{{ section.slug }}-tab">
                                {{ section.content }}

                                <hr/>

                                <div class="section-tools">
                                    {% assign nextSectionIndex = forloop.index0 | plus: 1 %}
                                    {% assign prevSectionIndex = forloop.index0 | minus: 1 %}

                                    {% unless forloop.first %}
                                        <button class="btn btn-outline-dark prevnext-button" data-navigate-to-section="{{ book.sections[prevSectionIndex].slug }}">&larr; {{ book.sections[prevSectionIndex].title }}</button>
                                    {% endunless %}
                                    {% unless forloop.last %}
                                        <button class="btn btn-outline-dark prevnext-button" data-navigate-to-section="{{ book.sections[nextSectionIndex].slug }}">{{ book.sections[nextSectionIndex].title }} &rarr;</button>
                                    {% endunless %}
                                </div>
                            </div>
                        {% endfor %}
                    </div>
                </div>
            </div>
        </div>
    </div>
    {% endif %}
</div>

<hr/>
{% if book.openbook %}
    <div class="support-banner mt-5">
        <p>{{ book.title }} is provided as an OpenBook. If you find this content helpful, send your contributions and messages to the author. Please see copyright.</p>
    </div>
{% endif %}
<div class="text-center">{{ book.title }} &copy; {{ book.author }}</div>

<script>
    // Click handler for previous/next section buttons
    $('.prevnext-button').each(function(index, button) {
        button.addEventListener('click', function() {
            const newSectionSlug = button.dataset.navigateToSection;
            window.location.hash = newSectionSlug;
            var newSectionButton = $(`#${newSectionSlug}-tab`);
            var tabTrigger = new bootstrap.Tab(newSectionButton);
            tabTrigger.show();
            var top = $('#bookSectionContent').offset().top - 50;
            window.scrollTo({ top: top, behavior: 'smooth' });
        });
    });
</script>

<script>
    // Click handler for the Section Navigation buttons
    var bookSectionTabButtons = [].slice.call(document.querySelectorAll('#bookSectionTabs button'));
    bookSectionTabButtons.forEach(function (button) {
        button.addEventListener('click', function (event) {
            // append section slug to url as hash
            window.location.hash = button.dataset.bookSectionSlug;

            // scroll to top
            var top = $('#bookSectionContent').offset().top - 50;
            window.scrollTo({ top: top, behavior: 'smooth' })
        });
    });
</script>

<script>
    // Handle if user navigates with hash
    $(document).ready(function() {
        if (!window.location.hash) return;
        var sectionSlug = window.location.hash;
        var sectionTab = $(`${sectionSlug}-tab`);
        if (!sectionTab) return;
        var triggerable = new bootstrap.Tab(sectionTab);
        triggerable.show();
        var top = $('#bookSectionContent').offset().top - 50;
        window.scrollTo({ top: top, behavior: 'smooth' })
    });
</script>
{% endblock %}